=================
Jupyter tutorials
=================

This section contains a collection of Jupyter notebooks used for different
lectures and tutorials based on Xsuite:

- `Overview of main Xsuite functionalities <https://github.com/xsuite/tutorial_cern_seminar>`_
- `Ring design <https://github.com/xsuite/tutorial_lattice_design>`_
- `Experimental beam line <https://github.com/xsuite/tutorial_experimental_beamline>`_
- `Slow extraction <https://github.com/xsuite/slow_extraction_tutorial>`_
- `PSB multiturn injection <https://github.com/xsuite/tutorial_psb_injection_chicane>`_
- `Spin tracking and polarization <https://github.com/xsuite/tutorial_spin>`_
- `LHC twiss and optics matching <https://github.com/xsuite/tutorial_twiss_and_match>`_
- `Basic beam dynamics and lattice design <https://github.com/xsuite/tutorial_introduction_rome2025>`_
- `Clic damping ring - survey, twiss, radiation <https://github.com/xsuite/tutorial_clic_damping_ring>`_
